import groovy.swing.SwingBuilder
import java.awt.Color
import java.awt.GridBagConstraints as GBC
import javax.swing.JTabbedPane
import javax.swing.WindowConstants as WC
import javax.swing.SwingConstants as SC
import javax.swing.DefaultListModel

def builder = new SwingBuilder();
def frame = builder.frame(id: "frame", title: "Create a new Plugin", defaultCloseOperation: WC.DISPOSE_ON_CLOSE) {
    gridBagLayout()
    def gbc = gbc(gridx: 0, gridy: 0, weightx: 1.0f, weighty: 1.0f, gridwidth: 1, gridheight: 1, fill: GBC.BOTH)
    // set up the labels.
    gbc.insets = [10, 10, 0, 0]
    gbc.gridx = 0
    gbc.gridy = 0
    gbc.weightx = 0.0f
    gbc.weighty = 0.0f
    label(text: "Action:", horizontalAlignment: SC.RIGHT, constraints: gbc)
    gbc.gridy++
    label(text: "Menu Item:", horizontalAlignment: SC.RIGHT, constraints: gbc)
    gbc.gridy++
    label(text: "Code:", horizontalAlignment: SC.RIGHT, verticalAlignment: SC.TOP, constraints: gbc)
    gbc.gridy++
    label(id: "description_label", text: "<html>+ <u>Description</u>:</html>", horizontalAlignment: SC.RIGHT, verticalAlignment: SC.TOP, constraints: gbc,
        mouseClicked: {
            description_scroll_pane.visible = !description_scroll_pane.visible
            if(description_scroll_pane.visible) {
                description_label.text = "<html>- <u>Description</u>:</html>"
            } else {
                description_label.text = "<html>+ <u>Description</u>:</html>"
            }
            frame.pack()
            frame.show()
        },
        mouseEntered: {
            description_label.foreground = Color.blue
        },
        mouseExited: {
            description_label.foreground = Color.black
        }
    )


   
    // set up fields
    gbc.gridx = 1
    gbc.gridy = 0
    gbc.weightx = 1.0f
    gbc.insets = [10, 5, 0, 10]
    panel(constraints: gbc) {
        gridBagLayout()
        gbc.gridx = 0
        gbc.insets = [0, 0, 0, 0]
        comboBox(id: "action_field", items: ["Action One", "Action Two", "Action Three"], constraints: gbc)
        gbc.gridx++
        gbc.weightx = 0.0f
        gbc.insets = [0, 2, 0, 0]
        button(text: "New", constraints: gbc)
    }
    gbc.gridx = 1
    gbc.gridy++
    gbc.weightx = 1.0f
    gbc.insets = [10, 5, 0, 10]
    checkBox(id: "menu_item_field", text: "<html>This action should be available from the Plugin's menu.</html>", horizontalTextPosition: SC.RIGHT, constraints: gbc)
    gbc.gridy++
    gbc.weighty = 1.0f
    scrollPane(constraints: gbc) {
        textArea(id: "code_field", text: "// Your BeanShell code.", columns: 40, rows: 4, lineWrap: true, wrapStyleWord: true, editable: false)
    }
    gbc.gridy++
    scrollPane(id: "description_scroll_pane", constraints: gbc, visible: false) {
        textArea(id: "description_field", text: "", columns: 40, rows: 4, lineWrap: true, wrapStyleWord: true, editable: false)
    }

	
    // add the buttons
    gbc.gridy++
    gbc.gridx = 0
    gbc.weighty = 0.0f
    gbc.gridwidth = 2
    panel(constraints: gbc) {
        gridBagLayout()
        gbc.gridx = 0
        gbc.gridy = 0
        gbc.weightx = 1.0f
        gbc.weighty = 0.0f
        gbc.gridwidth = 1
        gbc.gridheight = 1
        gbc.fill = GBC.BOTH
        gbc.insets = [5, 10, 10, 0]
        label(text: "", constraints: gbc)
        gbc.gridx++
        gbc.weightx = 0.0f
        button(text: "Save", constraints: gbc, actionPerformed: {frame.dispose()})
        gbc.gridx++
        button(text: "Cancel", constraints: gbc, actionPerformed: {frame.dispose()})
    }
}
frame.pack()
frame.setLocationRelativeTo(null)
frame.show()
